export function createScatterPlot() {
  let width;
  let height;
  let data;
  let xValue;
  let yValue;
  let margin;
  let radius;

  function chart(selection) {
    const xScale = d3
      .scaleLinear()
      .domain([0, d3.max(data, xValue)])
      .range([margin.left, width - margin.right]);

    const yScale = d3
      .scaleLinear()
      .domain([0, d3.max(data, yValue)])
      .range([height - margin.bottom, margin.top]);

    selection
      .selectAll('circle')
      .data(data)
      .join('circle')
      .attr('cx', (d) => xScale(xValue(d)))
      .attr('cy', (d) => yScale(yValue(d)))
      .attr('r', radius)
      .attr('fill', 'steelblue');
  }

  chart.width = function (_) {
    return arguments.length ? ((width = _), chart) : width;
  };

  chart.height = function (_) {
    return arguments.length
      ? ((height = _), chart)
      : height;
  };

  chart.data = function (_) {
    return arguments.length ? ((data = _), chart) : data;
  };

  chart.xValue = function (_) {
    return arguments.length
      ? ((xValue = _), chart)
      : xValue;
  };

  chart.yValue = function (_) {
    return arguments.length
      ? ((yValue = _), chart)
      : yValue;
  };

  chart.margin = function (_) {
    return arguments.length
      ? ((margin = _), chart)
      : margin;
  };

  chart.radius = function (_) {
    return arguments.length
      ? ((radius = _), chart)
      : radius;
  };

  return chart;
}
